@@ -11,7 +11,7 @@ fi
 
 echo "--------------------------------------------------------------------"
 echo
-echo "SoftEther VPN Server (Ver 4.04, Build 9412, Intel x86) for FreeBSD Install Utility"
+echo "SoftEther VPN Server (Ver 4.07, Build 9448, Intel x64 / AMD64) for FreeBSD Install Utility"
 echo "Copyright (c) SoftEther Project at University of Tsukuba, Japan. All Rights Reserved."
 echo
 echo "--------------------------------------------------------------------"
